@@ -54,6 +54,14 @@ var both = {
   }
 }
 
+var preversionOnly = {
+  name: 'scripted',
+  version: '1.2.3',
+  scripts: {
+    'preversion': 'echo preversion'
+  }
+}
+
 
 function testOutput (t, command, er, code, stdout, stderr) {
   var lines
@@ -192,6 +200,25 @@ test('npm run-script no-params (lifecycle only)', function (t) {
   })
 })
 
+test('npm run-script no-params (preversion only)', function (t) {
+  var expected = [
+    'Lifecycle scripts included in scripted:',
+    '  preversion',
+    '    echo preversion',
+    ''
+  ].join('\n')
+
+  writeMetadata(preversionOnly)
+
+  common.npm(['run-script'], opts, function (err, code, stdout, stderr) {
+    t.ifError(err, 'ran run-script without parameters without crashing')
+    t.notOk(code, 'npm exited without error code')
+    t.notOk(stderr, 'npm printed nothing to stderr')
+    t.equal(stdout, expected, 'got expected output')
+    t.end()
+  })
+})
+
 test('npm run-script no-params (direct only)', function (t) {
   var expected = [
     'Scripts available in scripted via `npm run-script`:',
